"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

function _react() {
  const data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

var _Tasks = require("./Tasks");

var _enums = require("./enums");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/**
 * Tasks 管理，根据 cwd 做区分
 */
class TaskManager {
  constructor() {
    this.api = void 0;
    this.tasks = {};
    this.currentCwd = '';
    this.send = void 0;
  }

  // 客户端消息触发器
  init(cwd, send) {
    var _this = this;

    return _asyncToGenerator(function* () {
      _this.currentCwd = cwd;
      _this.send = send;

      if (_this.tasks[cwd]) {
        return;
      }

      const opts = {
        cwd
      };
      _this.tasks[cwd] = {
        [_enums.TaskType.BUILD]: new _Tasks.BuildTask(opts),
        [_enums.TaskType.DEV]: new _Tasks.DevTask(opts),
        [_enums.TaskType.TEST]: new _Tasks.TestTask(opts),
        [_enums.TaskType.LINT]: new _Tasks.LintTask(opts),
        [_enums.TaskType.INSTALL]: new _Tasks.InstallTask(opts)
      };
      const projectTasks = _this.tasks[cwd];
      Object.keys(_this.tasks[cwd]).forEach(
      /*#__PURE__*/
      function () {
        var _ref = _asyncToGenerator(function* (taskType) {
          const task = projectTasks[taskType];
          yield task.init(_this.collector(_this.currentCwd, _this.send));
        });

        return function (_x) {
          return _ref.apply(this, arguments);
        };
      }());
    })();
  }

  getTask(type) {
    const currentProjectTasks = this.tasks[this.currentCwd];
    return currentProjectTasks[type];
  }
  /**
   * 获取全部 task 的状态
   */


  getTasksState() {
    var _this2 = this;

    return _asyncToGenerator(function* () {
      const currentProjectTasks = _this2.tasks[_this2.currentCwd];
      return Object.keys(currentProjectTasks).map(type => currentProjectTasks[type].getDetail());
    })();
  }

  getTaskDetail(type) {
    const currentProjectTasks = this.tasks[this.currentCwd];
    return currentProjectTasks[type].getDetail();
  }

  collector(currentCwd, send) {
    return (_ref2) => {
      let cwd = _ref2.cwd,
          otherData = _objectWithoutProperties(_ref2, ["cwd"]);

      if (currentCwd !== cwd) {
        return;
      }

      if (!send) {
        return;
      }

      send(otherData);
    };
  }

}

var _default = TaskManager;
exports.default = _default;