"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatLog = formatLog;
exports.formatEnv = formatEnv;
exports.getNpmClient = getNpmClient;
exports.isScriptKeyExist = exports.runCommand = exports.error = void 0;

function _react() {
  const data = _interopRequireDefault(require("react"));

  _react = function _react() {
    return data;
  };

  return data;
}

function _path() {
  const data = require("path");

  _path = function _path() {
    return data;
  };

  return data;
}

function _fs() {
  const data = require("fs");

  _fs = function _fs() {
    return data;
  };

  return data;
}

function _child_process() {
  const data = require("child_process");

  _child_process = function _child_process() {
    return data;
  };

  return data;
}

var _enums = require("../core/enums");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const error = (msg, name = 'TaskError') => {
  const err = new Error(msg);
  err.name = name;
  throw err;
};

exports.error = error;

const runCommand = (script, options = {}) => {
  options.env = _objectSpread({}, process.env, {}, options.env, {
    FORCE_COLOR: '1'
  });
  options.cwd = options.cwd || process.cwd();
  options.stdio = options.stdio || 'pipe';
  let sh = 'sh';
  let shFlag = '-c';

  if (process.platform === 'win32') {
    sh = process.env.comspec || 'cmd';
    shFlag = '/d /s /c';
    options.windowsVerbatimArguments = true;

    if (script.indexOf('./') === 0 || script.indexOf('.\\') === 0 || script.indexOf('../') === 0 || script.indexOf('..\\') === 0) {
      const splits = script.split(' ');
      splits[0] = (0, _path().join)(options.cwd, splits[0]);
      script = splits.join(' ');
    }
  }

  const proc = (0, _child_process().spawn)(sh, [shFlag, script], options);
  return proc;
};

exports.runCommand = runCommand;

const isScriptKeyExist = (pkgPath, key) => {
  if (!(0, _fs().existsSync)(pkgPath)) {
    return false;
  }

  let pkg = {};

  try {
    pkg = require(pkgPath);
  } catch (_) {
    console.log(_.stack);
    return false;
  }

  return !!(pkg.scripts && pkg.scripts[key]);
};

exports.isScriptKeyExist = isScriptKeyExist;

function formatLog(log) {
  return log;
}

function formatEnv(env) {
  const res = {};
  Object.keys(env).forEach(key => {
    if (env[key] === null) {
      return;
    }

    if (typeof env[key] === 'boolean') {
      res[key] = env[key] ? '1' : 'none';
    } else {
      res[key] = env[key];
    }
  });
  return res;
}

function getNpmClient() {
  try {
    (0, _child_process().execSync)('tnpm --version', {
      stdio: 'ignore'
    });
    return _enums.NpmClient.tnpm;
  } catch (e) {}

  try {
    (0, _child_process().execSync)('cnpm --version', {
      stdio: 'ignore'
    });
    return _enums.NpmClient.cnpm;
  } catch (e) {}

  try {
    (0, _child_process().execSync)('npm --version', {
      stdio: 'ignore'
    });
    return _enums.NpmClient.npm;
  } catch (e) {}

  try {
    (0, _child_process().execSync)('ayarn --version', {
      stdio: 'ignore'
    });
    return _enums.NpmClient.ayayn;
  } catch (e) {}

  try {
    (0, _child_process().execSync)('yarn --version', {
      stdio: 'ignore'
    });
    return _enums.NpmClient.yarn;
  } catch (e) {}

  try {
    (0, _child_process().execSync)('pnpm --version', {
      stdio: 'ignore'
    });
    return _enums.NpmClient.pnpm;
  } catch (e) {}

  return _enums.NpmClient.npm;
}